@@ -63,8 +63,8 @@ push(@$images,$example);
 print "Annotate...\n";
 $example=$model->Clone();
 $example->Label('Annotate');
-$example->Annotate(text=>'Magick',geometry=>'+0+20',font=>'Generic.ttf',
-  fill=>'gold',gravity=>'North',pointsize=>14);
+$example->Annotate(text=>'Magick',geometry=>'+0+20',fill=>'gold',
+  gravity=>'North',pointsize=>14);
 push(@$images,$example);
 
 print "Auto-gamma...\n";
@@ -79,6 +79,18 @@ $example->Label('Auto Level');
 $example->AutoLevel();
 push(@$images,$example);
 
+print "Auto-threshold...\n";
+$example=$model->Clone();
+$example->Label('Auto Threshold');
+$example->AutoThreshold();
+push(@$images,$example);
+
+print "Blilateral Blur...\n";
+$example=$model->Clone();
+$example->Label('Blilateral Blur');
+$example->BilateralBlur('8x8');
+push(@$images,$example);
+
 print "Blur...\n";
 $example=$model->Clone();
 $example->Label('Blur');
@@ -91,6 +103,12 @@ $example->Label('Border');
 $example->Border(geometry=>'6x6',color=>'gold');
 push(@$images,$example);
 
+print "CLAHE...\n";
+$example=$model->Clone();
+$example->Label('CLAHE');
+$example->CLAHE('128x192+32+3');
+push(@$images,$example);
+
 print "Channel...\n";
 $example=$model->Clone();
 $example->Label('Channel');
@@ -100,7 +118,7 @@ push(@$images,$example);
 print "Charcoal...\n";
 $example=$model->Clone();
 $example->Label('Charcoal');
-$example->Charcoal('0x1');
+$example->Charcoal('2x1');
 push(@$images,$example);
 
 print "ColorMatrix...\n";
@@ -109,6 +127,12 @@ $example->Label('ColorMatrix');
 $example->ColorMatrix([1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0.5, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1]);
 push(@$images,$example);
 
+print "Colorspace...\n";
+$example=$model->Clone();
+$example->Label('Colorspace');
+$example->Colorspace('Lab');
+push(@$images,$example);
+
 print "Composite...\n";
 $example=$model->Clone();
 $example->Label('Composite');
@@ -131,7 +155,7 @@ push(@$images,$example);
 print "Convolve...\n";
 $example=$model->Clone();
 $example->Label('Convolve');
-$example->Convolve([1, 1, 1, 1, 4, 1, 1, 1, 1]);
+$example->Convolve([0.125, 0.125, 0.125, 0.125, 0.5, 0.125, 0.125, 0.125, 0.125]);
 push(@$images,$example);
 
 print "Crop...\n";
@@ -163,7 +187,7 @@ push(@$images,$example);
 print "Detect Edges...\n";
 $example=$model->Clone();
 $example->Label('Detect Edges');
-$example->Edge();
+$example->Edge('2x0.5');
 $example->Clamp();
 push(@$images,$example);
 
@@ -185,7 +209,7 @@ $example->Label('Equalize');
 $example->Equalize();
 push(@$images,$example);
 
-print "Implode...\n";
+print "Explode...\n";
 $example=$model->Clone();
 $example->Label('Explode');
 $example->Implode(-1);
@@ -246,6 +270,12 @@ $example->Label('Implode');
 $example->Implode(0.5);
 push(@$images,$example);
 
+print "Kuwahara...\n";
+$example=$model->Clone();
+$example->Label('Kuwahara');
+$example->Kuwahara('0x1');
+push(@$images,$example);
+
 print "Level...\n";
 $example=$model->Clone();
 $example->Label('Level');
@@ -253,16 +283,22 @@ $example->Level('20%x');
 $example->Clamp();
 push(@$images,$example);
 
+print "Linear stretch...\n";
+$example=$model->Clone();
+$example->Label('Linear Stretch');
+$example->LinearStretch('5x5');
+push(@$images,$example);
+
 print "Median Filter...\n";
 $example=$model->Clone();
 $example->Label('Median Filter');
-$example->MedianFilter();
+$example->MedianFilter('4x4');
 push(@$images,$example);
 
 print "Mode...\n";
 $example=$model->Clone();
 $example->Label('Mode');
-$example->Mode();
+$example->Mode('4x4');
 push(@$images,$example);
 
 print "Modulate...\n";
@@ -305,7 +341,7 @@ push(@$images,$example);
 print "Oil Paint...\n";
 $example=$model->Clone();
 $example->Label('Oil Paint');
-$example->OilPaint();
+$example->OilPaint('2x0.5');
 push(@$images,$example);
 
 print "Plasma...\n";
@@ -334,10 +370,10 @@ $example->Label('Quantize');
 $example->Quantize();
 push(@$images,$example);
 
-print "Radial Blur...\n";
+print "Rotational Blur...\n";
 $example=$model->Clone();
-$example->Label('Radial Blur');
-$example->RadialBlur(10);
+$example->Label('Rotational Blur');
+$example->RotationalBlur(10);
 push(@$images,$example);
 
 print "Raise...\n";
@@ -349,7 +385,7 @@ push(@$images,$example);
 print "Reduce Noise...\n";
 $example=$model->Clone();
 $example->Label('Reduce Noise');
-$example->ReduceNoise();
+$example->ReduceNoise('2x2');
 push(@$images,$example);
 
 print "Resize...\n";
@@ -444,6 +480,12 @@ $example->Label('Swirl');
 $example->Swirl(90);
 push(@$images,$example);
 
+print "Tint...\n";
+$example=$model->Clone();
+$example->Label('Tint');
+$example->Tint('wheat');
+push(@$images,$example);
+
 print "Unsharp Mask...\n";
 $example=$model->Clone();
 $example->Label('Unsharp Mask');
@@ -462,14 +504,20 @@ $example=$model->Clone();
 $example->Label('Wave');
 $example->Wave('25x150');
 push(@$images,$example);
+
+print "WaveletDenoise...\n";
+$example=$model->Clone();
+$example->Label('Wavelet Denoise');
+$example->WaveletDenoise('5%');
+push(@$images,$example);
+
 #
 # Create image montage.
 #
 print "Montage...\n";
-$montage=$images->Montage(geometry=>'128x160+8+4>',gravity=>'Center',
-  tile=>'5x+10+200',compose=>'over',background=>'#ffffff',
-  font=>'Generic.ttf',pointsize=>18,fill=>'#600',stroke=>'none',
-  shadow=>'true');
+$montage=$images->Montage(geometry=>'140x160+8+4>',gravity=>'Center',
+  tile=>'5x+10+200',compose=>'over',background=>'#ffffff',pointsize=>18,
+  fill=>'#600',stroke=>'none',shadow=>'true');
 
 $logo=Image::Magick->new();
 $logo->Read('logo:');
